# settings.py used as data for testing Settings.load

# This should be read
UPPERCASE = True

# This should be ignored
lowercase = True

# This should also be ignored
import os  # noqa
